@@ -1,13 +1,24 @@
 
 use Test;
-BEGIN { plan tests => 2 };
-use GPS::Lowrance::Trail;
-ok(1); # If we made it this far, we're ok.
+BEGIN { plan tests => 6 };
+use GPS::Lowrance::Trail 0.20;
+ok(1);
 
 my $trail = new GPS::Lowrance::Trail;
 ok(defined $trail);
 
-exit 0;
+ok( $trail->size == 0 );
+
+$trail->add_point(0,0);
+ok( $trail->size == 1 );
+
+my $ref = $trail->get_trail();
+
+ok( ref($ref) eq "ARRAY" );
+ok( @$ref == $trail->size );
+
+# We need to test the conversions, although rounding errors could be
+# problematic.
 
 __END__
 
@@ -27,11 +38,9 @@ ok($trail->trail_num);
 
 ok($trail->size);
 
-my $fo = new FileHandle 'out.txt', O_WRONLY;
+my $fo = new FileHandle '>out.txt';
 ok(defined $fo);
 
 # $trail->write_lonlat( $fo );
 $trail->write_gdm16( $fo );
 
-
-
